cat_with_dtype

Macro cat_with_dtype 

macro_rules! cat_with_dtype {
    ($tensors: expr, $dim: expr, [$($dtype: ident),*]) => { ... };
}
๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Macro to execute a cat operation on a given set of element types.

Uses zero-copy views from storage for concatenation.

Panics

Since there is no automatic type cast at this time, binary operations for different floating point precision data types will panic with a data type mismatch.