execute_with_float_dtype

Macro execute_with_float_dtype 

macro_rules! execute_with_float_dtype {
    (($lhs:expr, $rhs:expr), $op:expr) => { ... };
    (($lhs:expr, $rhs:expr), $element:ident, $op:expr) => { ... };
    ($tensor:expr, $op:expr) => { ... };
    ($tensor:expr, $element:ident, $op:expr) => { ... };
}
๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Macro to execute an operation a given element type. Only handles float types.

Panics

Since there is no automatic type cast at this time, binary operations for different floating point precision data types will panic with a data type mismatch.