to_typed_dims

Macro to_typed_dims 

macro_rules! to_typed_dims {
    (
        $n:expr,
        $dims:expr,
        justdim
    ) => { ... };
}
👎Deprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Converts a slice of usize to a typed dimension.