AddAssignElement

Trait AddAssignElement 

pub trait AddAssignElement<Rhs = Self> {
    // Required method
    fn add_assign(&mut self, rhs: Rhs);
}
👎Deprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

The addition assignment operator implemented for ndarray elements.

Required Methods

fn add_assign(&mut self, rhs: Rhs)

👎Deprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Performs the addition assignment operation.

For bool, this corresponds to logical OR assignment.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl AddAssignElement for bool

Source

fn add_assign(&mut self, rhs: Self)

👎Deprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Implementors