ExpElement

Trait ExpElement 

pub trait ExpElement {
    // Required methods
    fn exp_elem(self) -> Self;
    fn log_elem(self) -> Self;
    fn log1p_elem(self) -> Self;
    fn powf_elem(self, value: f32) -> Self;
    fn powi_elem(self, value: i32) -> Self;
    fn sqrt_elem(self) -> Self;
    fn abs_elem(self) -> Self;
}
๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

A element for ndarray backend that supports exp ops.

Required Methods

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Exponent

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Log

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Log1p

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Powf

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Powi

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Sqrt

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Abs

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl ExpElement for f32

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for f64

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for i8

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for i16

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for i32

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for i64

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for u8

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for u16

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for u32

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

impl ExpElement for u64

Source

fn exp_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn log1p_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powf_elem(self, value: f32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn powi_elem(self, value: i32) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn sqrt_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Source

fn abs_elem(self) -> Self

๐Ÿ‘ŽDeprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Implementors