Crate burn_ndarray

Crate burn_ndarray 

👎Deprecated since 0.22.0:

burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.

Burn ndarray backend.

Deprecated: This backend is deprecated and will be removed in a future release. Please migrate to one of the actively maintained backends:

  • Flex (burn-flex) for portable pure-Rust CPU execution (std, no_std, WASM)
  • CubeCL backends (CUDA, ROCm, Vulkan, Metal, WebGPU) for GPU acceleration

See COMPARISON.md for an operation-by-operation migration path.

Macros

cat_with_dtypeDeprecated
Macro to execute a cat operation on a given set of element types.
execute_with_dtypeDeprecated
Macro to execute an operation on a given element type.
execute_with_float_dtypeDeprecated
Macro to execute an operation a given element type. Only handles float types.
execute_with_float_out_dtypeDeprecated
Macro to execute an operation that returns a given element type.
execute_with_int_dtypeDeprecated
Macro to execute an operation a given element type. Only handles int types.
execute_with_int_out_dtypeDeprecated
Macro to execute an operation that returns a given element type.
execute_with_numeric_dtypeDeprecated
Macro to execute an operation a given element type. Only handles numeric types
iter_parDeprecatedmulti-threads
Macro for iterating in parallel.
iter_range_parDeprecatedmulti-threads
Macro for iterating over a range in parallel.
iter_slice_parDeprecatedmulti-threads
Macro for iterating in parallel.
reshapeDeprecated
Reshapes an array into a tensor.
run_parDeprecatedmulti-threads
Macro for running a function in parallel.
sliceDeprecated
Slice a tensor
to_typed_dimsDeprecated
Converts a slice of usize to a typed dimension.

Structs

NdArrayDeprecated
Tensor backend that uses the ndarray crate for executing tensor operations.
NdArrayQTensorDeprecated
A quantized tensor for the ndarray backend.

Enums

NdArrayDeviceDeprecated
The device type for the ndarray backend.
NdArrayTensorDeprecated
Tensor primitive used by the ndarray backend.

Traits

AddAssignElementDeprecated
The addition assignment operator implemented for ndarray elements.
ExpElementDeprecated
A element for ndarray backend that supports exp ops.
FloatNdArrayElementDeprecated
A float element for ndarray backend.
IntNdArrayElementDeprecated
An int element for ndarray backend.
NdArrayElementDeprecated
A general element for ndarray backend.
QuantElementDeprecated
A quantized element for the ndarray backend.

Type Aliases

SharedArrayDeprecated
Concrete storage type for ndarray (owned with COW semantics via Arc)