👎Deprecated since 0.22.0:
burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.
Burn ndarray backend.
Deprecated: This backend is deprecated and will be removed in a future release. Please migrate to one of the actively maintained backends:
- Flex (
burn-flex) for portable pure-Rust CPU execution (std, no_std, WASM) - CubeCL backends (CUDA, ROCm, Vulkan, Metal, WebGPU) for GPU acceleration
See COMPARISON.md for an operation-by-operation migration path.
Macros
- cat_
with_ dtype Deprecated - Macro to execute a cat operation on a given set of element types.
- execute_
with_ dtype Deprecated - Macro to execute an operation on a given element type.
- execute_
with_ float_ dtype Deprecated - Macro to execute an operation a given element type. Only handles float types.
- execute_
with_ float_ out_ dtype Deprecated - Macro to execute an operation that returns a given element type.
- execute_
with_ int_ dtype Deprecated - Macro to execute an operation a given element type. Only handles int types.
- execute_
with_ int_ out_ dtype Deprecated - Macro to execute an operation that returns a given element type.
- execute_
with_ numeric_ dtype Deprecated - Macro to execute an operation a given element type. Only handles numeric types
- iter_
par Deprecated multi-threads - Macro for iterating in parallel.
- iter_
range_ par Deprecated multi-threads - Macro for iterating over a range in parallel.
- iter_
slice_ par Deprecated multi-threads - Macro for iterating in parallel.
- reshape
Deprecated - Reshapes an array into a tensor.
- run_par
Deprecated multi-threads - Macro for running a function in parallel.
- slice
Deprecated - Slice a tensor
- to_
typed_ dims Deprecated - Converts a slice of usize to a typed dimension.
Structs
- NdArray
Deprecated - Tensor backend that uses the ndarray crate for executing tensor operations.
- NdArrayQ
Tensor Deprecated - A quantized tensor for the ndarray backend.
Enums
- NdArray
Device Deprecated - The device type for the ndarray backend.
- NdArray
Tensor Deprecated - Tensor primitive used by the ndarray backend.
Traits
- AddAssign
Element Deprecated - The addition assignment operator implemented for ndarray elements.
- ExpElement
Deprecated - A element for ndarray backend that supports exp ops.
- Float
NdArray Element Deprecated - A float element for ndarray backend.
- IntNd
Array Element Deprecated - An int element for ndarray backend.
- NdArray
Element Deprecated - A general element for ndarray backend.
- Quant
Element Deprecated - A quantized element for the ndarray backend.
Type Aliases
- Shared
Array Deprecated - Concrete storage type for ndarray (owned with COW semantics via Arc)