pub struct NdArray;burn-ndarray is deprecated and will be removed in a future release. Use burn-flex for pure-Rust CPU execution (std, no_std, WebAssembly), or one of the CubeCL backends (burn-cuda, burn-rocm, burn-wgpu, burn-cpu) for GPU acceleration.
Tensor backend that uses the ndarray crate for executing tensor operations.
This backend is compatible with CPUs and can be compiled for almost any platform, including
wasm, arm, and x86.