pub struct NdArray;Expand description
Tensor backend that uses the ndarray crate for executing tensor operations.
This backend is compatible with CPUs and can be compiled for almost any platform, including
wasm, arm, and x86.